@@ -22,6 +22,7 @@ export default {
   'auto-accept edits': '自动接受编辑',
   'Accepting edits': '接受编辑',
   '(shift + tab to cycle)': '(shift + tab 切换)',
+  '(tab to cycle)': '(按 tab 切换)',
   'Execute shell commands via {{symbol}} (e.g., {{example1}}) or use natural language (e.g., {{example2}}).':
     '通过 {{symbol}} 执行 shell 命令（例如，{{example1}}）或使用自然语言（例如，{{example2}}）',
   '!': '!',
@@ -32,6 +33,25 @@ export default {
   'Model Context Protocol command (from external servers)':
     '模型上下文协议命令（来自外部服务器）',
   'Keyboard Shortcuts:': '键盘快捷键：',
+  'Toggle this help display': '切换此帮助显示',
+  'Toggle shell mode': '切换命令行模式',
+  'Open command menu': '打开命令菜单',
+  'Add file context': '添加文件上下文',
+  'Accept suggestion / Autocomplete': '接受建议 / 自动补全',
+  'Reverse search history': '反向搜索历史',
+  'Press ? again to close': '再次按 ? 关闭',
+  // Keyboard shortcuts panel descriptions
+  'for shell mode': '命令行模式',
+  'for commands': '命令菜单',
+  'for file paths': '文件路径',
+  'to clear input': '清空输入',
+  'to cycle approvals': '切换审批模式',
+  'to quit': '退出',
+  'for newline': '换行',
+  'to clear screen': '清屏',
+  'to search history': '搜索历史',
+  'to paste images': '粘贴图片',
+  'for external editor': '外部编辑器',
   'Jump through words in the input': '在输入中按单词跳转',
   'Close dialogs, cancel requests, or quit application':
     '关闭对话框、取消请求或退出应用程序',
@@ -45,6 +65,7 @@ export default {
   'Connecting to MCP servers... ({{connected}}/{{total}})':
     '正在连接到 MCP 服务器... ({{connected}}/{{total}})',
   'Type your message or @path/to/file': '输入您的消息或 @ 文件路径',
+  '? for shortcuts': '按 ? 查看快捷键',
   "Press 'i' for INSERT mode and 'Esc' for NORMAL mode.":
     "按 'i' 进入插入模式，按 'Esc' 进入普通模式",
   'Cancel operation / Clear input (double press)':
@@ -58,10 +79,15 @@ export default {
   'show version info': '显示版本信息',
   'submit a bug report': '提交错误报告',
   'About Qwen Code': '关于 Qwen Code',
+  Status: '状态',
 
   // ============================================================================
   // System Information Fields
   // ============================================================================
+  'Qwen Code': 'Qwen Code',
+  Runtime: '运行环境',
+  OS: '操作系统',
+  Auth: '认证',
   'CLI Version': 'CLI 版本',
   'Git Commit': 'Git 提交',
   Model: '模型',
@@ -74,6 +100,7 @@ export default {
   'Session ID': '会话 ID',
   'Auth Method': '认证方式',
   'Base URL': '基础 URL',
+  Proxy: '代理',
   'Memory Usage': '内存使用',
   'IDE Client': 'IDE 客户端',
 
@@ -88,20 +115,23 @@ export default {
   'No tools available': '没有可用工具',
   'View or change the approval mode for tool usage':
     '查看或更改工具使用的审批模式',
+  'Invalid approval mode "{{arg}}". Valid modes: {{modes}}':
+    '无效的审批模式 "{{arg}}"。有效模式：{{modes}}',
+  'Approval mode set to "{{mode}}"': '审批模式已设置为 "{{mode}}"',
   'View or change the language setting': '查看或更改语言设置',
   'change the theme': '更改主题',
   'Select Theme': '选择主题',
   Preview: '预览',
   '(Use Enter to select, Tab to configure scope)':
     '（使用 Enter 选择，Tab 配置作用域）',
-  '(Use Enter to apply scope, Tab to select theme)':
-    '（使用 Enter 应用作用域，Tab 选择主题）',
+  '(Use Enter to apply scope, Tab to go back)':
+    '（使用 Enter 应用作用域，Tab 返回）',
   'Theme configuration unavailable due to NO_COLOR env variable.':
     '由于 NO_COLOR 环境变量，主题配置不可用。',
   'Theme "{{themeName}}" not found.': '未找到主题 "{{themeName}}"。',
   'Theme "{{themeName}}" not found in selected scope.':
     '在所选作用域中未找到主题 "{{themeName}}"。',
-  'clear the screen and conversation history': '清屏并清除对话历史',
+  'Clear conversation history and free up context': '清除对话历史并释放上下文',
   'Compresses the context by replacing it with a summary.':
     '通过用摘要替换来压缩上下文',
   'open full Qwen Code documentation in your browser':
@@ -146,6 +176,7 @@ export default {
   'Project Level ({{path}})': '项目级 ({{path}})',
   'User Level ({{path}})': '用户级 ({{path}})',
   'Built-in Agents': '内置代理',
+  'Extension Agents': '扩展代理',
   'Using: {{count}} agents': '使用中: {{count}} 个代理',
   'View Agent': '查看代理',
   'Edit Agent': '编辑代理',
@@ -245,33 +276,41 @@ export default {
   // ============================================================================
   'View and edit Qwen Code settings': '查看和编辑 Qwen Code 设置',
   Settings: '设置',
-  '(Use Enter to select{{tabText}})': '（使用 Enter 选择{{tabText}}）',
-  ', Tab to change focus': '，Tab 切换焦点',
   'To see changes, Qwen Code must be restarted. Press r to exit and apply changes now.':
     '要查看更改，必须重启 Qwen Code。按 r 退出并立即应用更改。',
+  'The command "/{{command}}" is not supported in non-interactive mode.':
+    '不支持在非交互模式下使用命令 "/{{command}}"。',
   // ============================================================================
   // Settings Labels
   // ============================================================================
   'Vim Mode': 'Vim 模式',
   'Disable Auto Update': '禁用自动更新',
+  'Attribution: commit': '署名：提交',
+  'Terminal Bell Notification': '终端响铃通知',
+  'Enable Usage Statistics': '启用使用统计',
+  Theme: '主题',
+  'Preferred Editor': '首选编辑器',
+  'Auto-connect to IDE': '自动连接到 IDE',
   'Enable Prompt Completion': '启用提示补全',
   'Debug Keystroke Logging': '调试按键记录',
-  Language: '语言',
+  'Language: UI': '语言：界面',
+  'Language: Model': '语言：模型',
   'Output Format': '输出格式',
   'Hide Window Title': '隐藏窗口标题',
   'Show Status in Title': '在标题中显示状态',
   'Hide Tips': '隐藏提示',
-  'Hide Banner': '隐藏横幅',
-  'Hide Context Summary': '隐藏上下文摘要',
-  'Hide CWD': '隐藏当前工作目录',
-  'Hide Sandbox Status': '隐藏沙箱状态',
-  'Hide Model Info': '隐藏模型信息',
-  'Hide Footer': '隐藏页脚',
-  'Show Memory Usage': '显示内存使用',
-  'Show Line Numbers': '显示行号',
+  'Show Line Numbers in Code': '在代码中显示行号',
   'Show Citations': '显示引用',
   'Custom Witty Phrases': '自定义诙谐短语',
-  'Enable Welcome Back': '启用欢迎回来',
+  'Show Welcome Back Dialog': '显示欢迎回来对话框',
+  'Enable User Feedback': '启用用户反馈',
+  'How is Qwen doing this session? (optional)': 'Qwen 这次表现如何？（可选）',
+  Bad: '不满意',
+  Fine: '还行',
+  Good: '满意',
+  Dismiss: '忽略',
+  'Not Sure Yet': '暂不评价',
+  'Any other key': '任意其他键',
   'Disable Loading Phrases': '禁用加载短语',
   'Screen Reader Mode': '屏幕阅读器模式',
   'IDE Mode': 'IDE 模式',
@@ -290,7 +329,7 @@ export default {
   'Respect .qwenignore': '遵守 .qwenignore',
   'Enable Recursive File Search': '启用递归文件搜索',
   'Disable Fuzzy Search': '禁用模糊搜索',
-  'Enable Interactive Shell': '启用交互式 Shell',
+  'Interactive Shell (PTY)': '交互式 Shell (PTY)',
   'Show Color': '显示颜色',
   'Auto Accept': '自动接受',
   'Use Ripgrep': '使用 Ripgrep',
@@ -300,6 +339,8 @@ export default {
   'Tool Output Truncation Lines': '工具输出截断行数',
   'Folder Trust': '文件夹信任',
   'Vision Model Preview': '视觉模型预览',
+  'Tool Schema Compliance': '工具 Schema 兼容性',
+  'Experimental: Skills': '实验性: 技能',
   // Settings enum options
   'Auto (detect from system)': '自动（从系统检测）',
   Text: '文本',
@@ -321,10 +362,160 @@ export default {
     '将目录添加到工作区。使用逗号分隔多个路径',
   'Show all directories in the workspace': '显示工作区中的所有目录',
   'set external editor preference': '设置外部编辑器首选项',
+  'Select Editor': '选择编辑器',
+  'Editor Preference': '编辑器首选项',
+  'These editors are currently supported. Please note that some editors cannot be used in sandbox mode.':
+    '当前支持以下编辑器。请注意，某些编辑器无法在沙箱模式下使用。',
+  'Your preferred editor is:': '您的首选编辑器是：',
   'Manage extensions': '管理扩展',
   'List active extensions': '列出活动扩展',
   'Update extensions. Usage: update <extension-names>|--all':
     '更新扩展。用法：update <extension-names>|--all',
+  'Disable an extension': '禁用扩展',
+  'Enable an extension': '启用扩展',
+  'Install an extension from a git repo or local path':
+    '从 Git 仓库或本地路径安装扩展',
+  'Uninstall an extension': '卸载扩展',
+  'No extensions installed.': '未安装扩展。',
+  'Usage: /extensions update <extension-names>|--all':
+    '用法：/extensions update <扩展名>|--all',
+  'Extension "{{name}}" not found.': '未找到扩展 "{{name}}"。',
+  'No extensions to update.': '没有可更新的扩展。',
+  'Usage: /extensions install <source>': '用法：/extensions install <来源>',
+  'Installing extension from "{{source}}"...':
+    '正在从 "{{source}}" 安装扩展...',
+  'Extension "{{name}}" installed successfully.': '扩展 "{{name}}" 安装成功。',
+  'Failed to install extension from "{{source}}": {{error}}':
+    '从 "{{source}}" 安装扩展失败：{{error}}',
+  'Usage: /extensions uninstall <extension-name>':
+    '用法：/extensions uninstall <扩展名>',
+  'Uninstalling extension "{{name}}"...': '正在卸载扩展 "{{name}}"...',
+  'Extension "{{name}}" uninstalled successfully.':
+    '扩展 "{{name}}" 卸载成功。',
+  'Failed to uninstall extension "{{name}}": {{error}}':
+    '卸载扩展 "{{name}}" 失败：{{error}}',
+  'Usage: /extensions {{command}} <extension> [--scope=<user|workspace>]':
+    '用法：/extensions {{command}} <扩展> [--scope=<user|workspace>]',
+  'Unsupported scope "{{scope}}", should be one of "user" or "workspace"':
+    '不支持的作用域 "{{scope}}"，应为 "user" 或 "workspace"',
+  'Extension "{{name}}" disabled for scope "{{scope}}"':
+    '扩展 "{{name}}" 已在作用域 "{{scope}}" 中禁用',
+  'Extension "{{name}}" enabled for scope "{{scope}}"':
+    '扩展 "{{name}}" 已在作用域 "{{scope}}" 中启用',
+  'Do you want to continue? [Y/n]: ': '是否继续？[Y/n]：',
+  'Do you want to continue?': '是否继续？',
+  'Installing extension "{{name}}".': '正在安装扩展 "{{name}}"。',
+  '**Extensions may introduce unexpected behavior. Ensure you have investigated the extension source and trust the author.**':
+    '**扩展可能会引入意外行为。请确保您已调查过扩展源并信任作者。**',
+  'This extension will run the following MCP servers:':
+    '此扩展将运行以下 MCP 服务器：',
+  local: '本地',
+  remote: '远程',
+  'This extension will add the following commands: {{commands}}.':
+    '此扩展将添加以下命令：{{commands}}。',
+  'This extension will append info to your QWEN.md context using {{fileName}}':
+    '此扩展将使用 {{fileName}} 向您的 QWEN.md 上下文追加信息',
+  'This extension will exclude the following core tools: {{tools}}':
+    '此扩展将排除以下核心工具：{{tools}}',
+  'This extension will install the following skills:': '此扩展将安装以下技能：',
+  'This extension will install the following subagents:':
+    '此扩展将安装以下子代理：',
+  'Installation cancelled for "{{name}}".': '已取消安装 "{{name}}"。',
+  '--ref and --auto-update are not applicable for marketplace extensions.':
+    '--ref 和 --auto-update 不适用于市场扩展。',
+  'Extension "{{name}}" installed successfully and enabled.':
+    '扩展 "{{name}}" 安装成功并已启用。',
+  'Installs an extension from a git repository URL, local path, or claude marketplace (marketplace-url:plugin-name).':
+    '从 Git 仓库 URL、本地路径或 Claude 市场（marketplace-url:plugin-name）安装扩展。',
+  'The github URL, local path, or marketplace source (marketplace-url:plugin-name) of the extension to install.':
+    '要安装的扩展的 GitHub URL、本地路径或市场源（marketplace-url:plugin-name）。',
+  'The git ref to install from.': '要安装的 Git 引用。',
+  'Enable auto-update for this extension.': '为此扩展启用自动更新。',
+  'Enable pre-release versions for this extension.': '为此扩展启用预发布版本。',
+  'Acknowledge the security risks of installing an extension and skip the confirmation prompt.':
+    '确认安装扩展的安全风险并跳过确认提示。',
+  'The source argument must be provided.': '必须提供来源参数。',
+  'Extension "{{name}}" successfully uninstalled.':
+    '扩展 "{{name}}" 卸载成功。',
+  'Uninstalls an extension.': '卸载扩展。',
+  'The name or source path of the extension to uninstall.':
+    '要卸载的扩展的名称或源路径。',
+  'Please include the name of the extension to uninstall as a positional argument.':
+    '请将要卸载的扩展名称作为位置参数。',
+  'Enables an extension.': '启用扩展。',
+  'The name of the extension to enable.': '要启用的扩展名称。',
+  'The scope to enable the extenison in. If not set, will be enabled in all scopes.':
+    '启用扩展的作用域。如果未设置，将在所有作用域中启用。',
+  'Extension "{{name}}" successfully enabled for scope "{{scope}}".':
+    '扩展 "{{name}}" 已在作用域 "{{scope}}" 中启用。',
+  'Extension "{{name}}" successfully enabled in all scopes.':
+    '扩展 "{{name}}" 已在所有作用域中启用。',
+  'Invalid scope: {{scope}}. Please use one of {{scopes}}.':
+    '无效的作用域：{{scope}}。请使用 {{scopes}} 之一。',
+  'Disables an extension.': '禁用扩展。',
+  'The name of the extension to disable.': '要禁用的扩展名称。',
+  'The scope to disable the extenison in.': '禁用扩展的作用域。',
+  'Extension "{{name}}" successfully disabled for scope "{{scope}}".':
+    '扩展 "{{name}}" 已在作用域 "{{scope}}" 中禁用。',
+  'Extension "{{name}}" successfully updated: {{oldVersion}} → {{newVersion}}.':
+    '扩展 "{{name}}" 更新成功：{{oldVersion}} → {{newVersion}}。',
+  'Unable to install extension "{{name}}" due to missing install metadata':
+    '由于缺少安装元数据，无法安装扩展 "{{name}}"',
+  'Extension "{{name}}" is already up to date.':
+    '扩展 "{{name}}" 已是最新版本。',
+  'Updates all extensions or a named extension to the latest version.':
+    '将所有扩展或指定扩展更新到最新版本。',
+  'The name of the extension to update.': '要更新的扩展名称。',
+  'Update all extensions.': '更新所有扩展。',
+  'Either an extension name or --all must be provided':
+    '必须提供扩展名称或 --all',
+  'Lists installed extensions.': '列出已安装的扩展。',
+  'Path:': '路径：',
+  'Source:': '来源：',
+  'Type:': '类型：',
+  'Ref:': '引用：',
+  'Release tag:': '发布标签：',
+  'Enabled (User):': '已启用（用户）：',
+  'Enabled (Workspace):': '已启用（工作区）：',
+  'Context files:': '上下文文件：',
+  'Skills:': '技能：',
+  'Agents:': '代理：',
+  'MCP servers:': 'MCP 服务器：',
+  'Link extension failed to install.': '链接扩展安装失败。',
+  'Extension "{{name}}" linked successfully and enabled.':
+    '扩展 "{{name}}" 链接成功并已启用。',
+  'Links an extension from a local path. Updates made to the local path will always be reflected.':
+    '从本地路径链接扩展。对本地路径的更新将始终反映。',
+  'The name of the extension to link.': '要链接的扩展名称。',
+  'Set a specific setting for an extension.': '为扩展设置特定配置。',
+  'Name of the extension to configure.': '要配置的扩展名称。',
+  'The setting to configure (name or env var).':
+    '要配置的设置（名称或环境变量）。',
+  'The scope to set the setting in.': '设置配置的作用域。',
+  'List all settings for an extension.': '列出扩展的所有设置。',
+  'Name of the extension.': '扩展名称。',
+  'Extension "{{name}}" has no settings to configure.':
+    '扩展 "{{name}}" 没有可配置的设置。',
+  'Settings for "{{name}}":': '"{{name}}" 的设置：',
+  '(workspace)': '（工作区）',
+  '(user)': '（用户）',
+  '[not set]': '［未设置］',
+  '[value stored in keychain]': '［值存储在钥匙串中］',
+  'Manage extension settings.': '管理扩展设置。',
+  'You need to specify a command (set or list).':
+    '您需要指定命令（set 或 list）。',
+  // ============================================================================
+  // Plugin Choice / Marketplace
+  // ============================================================================
+  'No plugins available in this marketplace.': '此市场中没有可用的插件。',
+  'Select a plugin to install from marketplace "{{name}}":':
+    '从市场 "{{name}}" 中选择要安装的插件：',
+  'Plugin selection cancelled.': '插件选择已取消。',
+  'Select a plugin from "{{name}}"': '从 "{{name}}" 中选择插件',
+  'Use ↑↓ or j/k to navigate, Enter to select, Escape to cancel':
+    '使用 ↑↓ 或 j/k 导航，回车选择，Esc 取消',
+  '{{count}} more above': '上方还有 {{count}} 项',
+  '{{count}} more below': '下方还有 {{count}} 项',
   'manage IDE integration': '管理 IDE 集成',
   'check status of IDE integration': '检查 IDE 集成状态',
   'install required IDE companion for {{ideName}}':
@@ -369,8 +560,8 @@ export default {
   // ============================================================================
   // Commands - Language
   // ============================================================================
-  'Invalid language. Available: en-US, zh-CN':
-    '无效的语言。可用选项：en-US, zh-CN',
+  'Invalid language. Available: {{options}}':
+    '无效的语言。可用选项：{{options}}',
   'Language subcommands do not accept additional arguments.':
     '语言子命令不接受额外参数',
   'Current UI language: {{lang}}': '当前 UI 语言：{{lang}}',
@@ -378,12 +569,14 @@ export default {
   'LLM output language not set': '未设置 LLM 输出语言',
   'Set UI language': '设置 UI 语言',
   'Set LLM output language': '设置 LLM 输出语言',
-  'Usage: /language ui [zh-CN|en-US]': '用法：/language ui [zh-CN|en-US]',
+  'Usage: /language ui [{{options}}]': '用法：/language ui [{{options}}]',
   'Usage: /language output <language>': '用法：/language output <语言>',
   'Example: /language output 中文': '示例：/language output 中文',
   'Example: /language output English': '示例：/language output English',
   'Example: /language output 日本語': '示例：/language output 日本語',
+  'Example: /language output Português': '示例：/language output Português',
   'UI language changed to {{lang}}': 'UI 语言已更改为 {{lang}}',
+  'LLM output language set to {{lang}}': 'LLM 输出语言已设置为 {{lang}}',
   'LLM output language rule file generated at {{path}}':
     'LLM 输出语言规则文件已生成于 {{path}}',
   'Please restart the application for the changes to take effect.':
@@ -395,16 +588,12 @@ export default {
   'To request additional UI language packs, please open an issue on GitHub.':
     '如需请求其他 UI 语言包，请在 GitHub 上提交 issue',
   'Available options:': '可用选项：',
-  '  - zh-CN: Simplified Chinese': '  - zh-CN: 简体中文',
-  '  - en-US: English': '  - en-US: English',
-  'Set UI language to Simplified Chinese (zh-CN)':
-    '将 UI 语言设置为简体中文 (zh-CN)',
-  'Set UI language to English (en-US)': '将 UI 语言设置为英语 (en-US)',
+  'Set UI language to {{name}}': '将 UI 语言设置为 {{name}}',
 
   // ============================================================================
   // Commands - Approval Mode
   // ============================================================================
-  'Approval Mode': '审批模式',
+  'Tool Approval Mode': '工具审批模式',
   'Current approval mode: {{mode}}': '当前审批模式：{{mode}}',
   'Available approval modes:': '可用的审批模式：',
   'Approval mode changed to: {{mode}}': '审批模式已更改为：{{mode}}',
@@ -438,8 +627,6 @@ export default {
   'Automatically approve all tools': '自动批准所有工具',
   'Workspace approval mode exists and takes priority. User-level change will have no effect.':
     '工作区审批模式已存在并具有优先级。用户级别的更改将无效。',
-  '(Use Enter to select, Tab to change focus)':
-    '（使用 Enter 选择，Tab 切换焦点）',
   'Apply To': '应用于',
   'User Settings': '用户设置',
   'Workspace Settings': '工作区设置',
@@ -559,6 +746,12 @@ export default {
   'No conversation found to summarize.': '未找到要总结的对话',
   'Failed to generate project context summary: {{error}}':
     '生成项目上下文摘要失败：{{error}}',
+  'Saved project summary to {{filePathForDisplay}}.':
+    '项目摘要已保存到 {{filePathForDisplay}}',
+  'Saving project summary...': '正在保存项目摘要...',
+  'Generating project summary...': '正在生成项目摘要...',
+  'Failed to generate summary - no text content received from LLM response':
+    '生成摘要失败 - 未从 LLM 响应中接收到文本内容',
 
   // ============================================================================
   // Commands - Model
@@ -572,8 +765,9 @@ export default {
   // ============================================================================
   // Commands - Clear
   // ============================================================================
-  'Clearing terminal and resetting chat.': '正在清屏并重置聊天',
-  'Clearing terminal.': '正在清屏',
+  'Starting a new session, resetting chat, and clearing terminal.':
+    '正在开始新会话，重置聊天并清屏。',
+  'Starting a new session and clearing.': '正在开始新会话并清屏。',
 
   // ============================================================================
   // Commands - Compress
@@ -601,8 +795,8 @@ export default {
   'The /directory add command is not supported in restrictive sandbox profiles. Please use --include-directories when starting the session instead.':
     '/directory add 命令在限制性沙箱配置文件中不受支持。请改为在启动会话时使用 --include-directories。',
   "Error adding '{{path}}': {{error}}": "添加 '{{path}}' 时出错：{{error}}",
-  'Successfully added GEMINI.md files from the following directories if there are:\n- {{directories}}':
-    '如果存在，已成功从以下目录添加 GEMINI.md 文件：\n- {{directories}}',
+  'Successfully added QWEN.md files from the following directories if there are:\n- {{directories}}':
+    '如果存在，已成功从以下目录添加 QWEN.md 文件：\n- {{directories}}',
   'Error refreshing memory: {{error}}': '刷新内存时出错：{{error}}',
   'Successfully added directories:\n- {{directories}}':
     '成功添加目录：\n- {{directories}}',
@@ -715,6 +909,21 @@ export default {
   'Authentication timed out. Please try again.': '认证超时。请重试。',
   'Waiting for auth... (Press ESC or CTRL+C to cancel)':
     '正在等待认证...（按 ESC 或 CTRL+C 取消）',
+  'Missing API key for OpenAI-compatible auth. Set settings.security.auth.apiKey, or set the {{envKeyHint}} environment variable.':
+    '缺少 OpenAI 兼容认证的 API 密钥。请设置 settings.security.auth.apiKey 或设置 {{envKeyHint}} 环境变量。',
+  '{{envKeyHint}} environment variable not found.':
+    '未找到 {{envKeyHint}} 环境变量。',
+  '{{envKeyHint}} environment variable not found. Please set it in your .env file or environment variables.':
+    '未找到 {{envKeyHint}} 环境变量。请在 .env 文件或系统环境变量中进行设置。',
+  '{{envKeyHint}} environment variable not found (or set settings.security.auth.apiKey). Please set it in your .env file or environment variables.':
+    '未找到 {{envKeyHint}} 环境变量（或设置 settings.security.auth.apiKey）。请在 .env 文件或系统环境变量中进行设置。',
+  'Missing API key for OpenAI-compatible auth. Set the {{envKeyHint}} environment variable.':
+    '缺少 OpenAI 兼容认证的 API 密钥。请设置 {{envKeyHint}} 环境变量。',
+  'Anthropic provider missing required baseUrl in modelProviders[].baseUrl.':
+    'Anthropic 提供商缺少必需的 baseUrl，请在 modelProviders[].baseUrl 中配置。',
+  'ANTHROPIC_BASE_URL environment variable not found.':
+    '未找到 ANTHROPIC_BASE_URL 环境变量。',
+  'Invalid auth method selected.': '选择了无效的认证方式。',
   'Failed to authenticate. Message: {{message}}': '认证失败。消息：{{message}}',
   'Authenticated successfully with {{authType}} credentials.':
     '使用 {{authType}} 凭据成功认证。',
@@ -734,6 +943,15 @@ export default {
   // ============================================================================
   'Select Model': '选择模型',
   '(Press Esc to close)': '（按 Esc 关闭）',
+  'Current (effective) configuration': '当前（实际生效）配置',
+  AuthType: '认证方式',
+  'API Key': 'API 密钥',
+  unset: '未设置',
+  '(default)': '(默认)',
+  '(set)': '(已设置)',
+  '(not set)': '(未设置)',
+  "Failed to switch model to '{{modelId}}'.\n\n{{error}}":
+    "无法切换到模型 '{{modelId}}'.\n\n{{error}}",
   'The latest Qwen Coder model from Alibaba Cloud ModelStudio (version: qwen3-coder-plus-2025-09-23)':
     '来自阿里云 ModelStudio 的最新 Qwen Coder 模型（版本：qwen3-coder-plus-2025-09-23）',
   'The latest Qwen Vision model from Alibaba Cloud ModelStudio (version: qwen3-vl-plus-2025-09-23)':
@@ -808,13 +1026,24 @@ export default {
   // ============================================================================
   // Startup Tips
   // ============================================================================
-  'Tips for getting started:': '入门提示：',
-  '1. Ask questions, edit files, or run commands.':
-    '1. 提问、编辑文件或运行命令',
-  '2. Be specific for the best results.': '2. 具体描述以获得最佳结果',
-  'files to customize your interactions with Qwen Code.':
-    '文件以自定义您与 Qwen Code 的交互',
-  'for more information.': '获取更多信息',
+  'Tips:': '提示：',
+  'Use /compress when the conversation gets long to summarize history and free up context.':
+    '对话变长时用 /compress，总结历史并释放上下文。',
+  'Start a fresh idea with /clear or /new; the previous session stays available in history.':
+    '用 /clear 或 /new 开启新思路；之前的会话会保留在历史记录中。',
+  'Use /bug to submit issues to the maintainers when something goes off.':
+    '遇到问题时，用 /bug 将问题提交给维护者。',
+  'Switch auth type quickly with /auth.': '用 /auth 快速切换认证方式。',
+  'You can run any shell commands from Qwen Code using ! (e.g. !ls).':
+    '在 Qwen Code 中使用 ! 可运行任意 shell 命令（例如 !ls）。',
+  'Type / to open the command popup; Tab autocompletes slash commands and saved prompts.':
+    '输入 / 打开命令弹窗；按 Tab 自动补全斜杠命令和保存的提示词。',
+  'You can resume a previous conversation by running qwen --continue or qwen --resume.':
+    '运行 qwen --continue 或 qwen --resume 可继续之前的会话。',
+  'You can switch permission mode quickly with Shift+Tab or /approval-mode.':
+    '按 Shift+Tab 或输入 /approval-mode 可快速切换权限模式。',
+  'You can switch permission mode quickly with Tab or /approval-mode.':
+    '按 Tab 或输入 /approval-mode 可快速切换权限模式。',
 
   // ============================================================================
   // Exit Screen / Stats
@@ -836,11 +1065,11 @@ export default {
   'Session Stats': '会话统计',
   'Model Usage': '模型使用情况',
   Reqs: '请求数',
-  'Input Tokens': '输入令牌',
-  'Output Tokens': '输出令牌',
+  'Input Tokens': '输入 token 数',
+  'Output Tokens': '输出 token 数',
   'Savings Highlight:': '节省亮点：',
   'of input tokens were served from the cache, reducing costs.':
-    '的输入令牌来自缓存，降低了成本',
+    '从缓存载入 token ，降低了成本',
   'Tip: For a full token breakdown, run `/stats model`.':
     '提示：要查看完整的令牌明细，请运行 `/stats model`',
   'Model Stats For Nerds': '模型统计（技术细节）',
@@ -874,170 +1103,101 @@ export default {
   'Session start time is unavailable, cannot calculate stats.':
     '会话开始时间不可用，无法计算统计信息',
 
+  // ============================================================================
+  // Command Format Migration
+  // ============================================================================
+  'Command Format Migration': '命令格式迁移',
+  'Found {{count}} TOML command file:': '发现 {{count}} 个 TOML 命令文件：',
+  'Found {{count}} TOML command files:': '发现 {{count}} 个 TOML 命令文件：',
+  '... and {{count}} more': '... 以及其他 {{count}} 个',
+  'The TOML format is deprecated. Would you like to migrate them to Markdown format?':
+    'TOML 格式已弃用。是否将它们迁移到 Markdown 格式？',
+  '(Backups will be created and original files will be preserved)':
+    '（将创建备份，原始文件将保留）',
+
   // ============================================================================
   // Loading Phrases
   // ============================================================================
   'Waiting for user confirmation...': '等待用户确认...',
   '(esc to cancel, {{time}})': '（按 esc 取消，{{time}}）',
-  "I'm Feeling Lucky": '我感觉很幸运',
-  'Shipping awesomeness... ': '正在运送精彩内容... ',
-  'Painting the serifs back on...': '正在重新绘制衬线...',
-  'Navigating the slime mold...': '正在导航粘液霉菌...',
-  'Consulting the digital spirits...': '正在咨询数字精灵...',
-  'Reticulating splines...': '正在网格化样条曲线...',
-  'Warming up the AI hamsters...': '正在预热 AI 仓鼠...',
-  'Asking the magic conch shell...': '正在询问魔法海螺壳...',
-  'Generating witty retort...': '正在生成机智的反驳...',
-  'Polishing the algorithms...': '正在打磨算法...',
-  "Don't rush perfection (or my code)...": '不要急于追求完美（或我的代码）...',
-  'Brewing fresh bytes...': '正在酿造新鲜字节...',
-  'Counting electrons...': '正在计算电子...',
-  'Engaging cognitive processors...': '正在启动认知处理器...',
-  'Checking for syntax errors in the universe...':
-    '正在检查宇宙中的语法错误...',
-  'One moment, optimizing humor...': '稍等片刻，正在优化幽默感...',
-  'Shuffling punchlines...': '正在洗牌笑点...',
-  'Untangling neural nets...': '正在解开神经网络...',
-  'Compiling brilliance...': '正在编译智慧...',
-  'Loading wit.exe...': '正在加载 wit.exe...',
-  'Summoning the cloud of wisdom...': '正在召唤智慧云...',
-  'Preparing a witty response...': '正在准备机智的回复...',
-  "Just a sec, I'm debugging reality...": '稍等片刻，我正在调试现实...',
-  'Confuzzling the options...': '正在混淆选项...',
-  'Tuning the cosmic frequencies...': '正在调谐宇宙频率...',
-  'Crafting a response worthy of your patience...':
-    '正在制作值得您耐心等待的回复...',
-  'Compiling the 1s and 0s...': '正在编译 1 和 0...',
-  'Resolving dependencies... and existential crises...':
-    '正在解决依赖关系...和存在主义危机...',
-  'Defragmenting memories... both RAM and personal...':
-    '正在整理记忆碎片...包括 RAM 和个人记忆...',
-  'Rebooting the humor module...': '正在重启幽默模块...',
-  'Caching the essentials (mostly cat memes)...':
-    '正在缓存必需品（主要是猫咪表情包）...',
-  'Optimizing for ludicrous speed': '正在优化到荒谬的速度',
-  "Swapping bits... don't tell the bytes...": '正在交换位...不要告诉字节...',
-  'Garbage collecting... be right back...': '正在垃圾回收...马上回来...',
-  'Assembling the interwebs...': '正在组装互联网...',
-  'Converting coffee into code...': '正在将咖啡转换为代码...',
-  'Updating the syntax for reality...': '正在更新现实的语法...',
-  'Rewiring the synapses...': '正在重新连接突触...',
-  'Looking for a misplaced semicolon...': '正在寻找放错位置的分号...',
-  "Greasin' the cogs of the machine...": '正在给机器的齿轮上油...',
-  'Pre-heating the servers...': '正在预热服务器...',
-  'Calibrating the flux capacitor...': '正在校准通量电容器...',
-  'Engaging the improbability drive...': '正在启动不可能性驱动器...',
-  'Channeling the Force...': '正在引导原力...',
-  'Aligning the stars for optimal response...': '正在对齐星星以获得最佳回复...',
-  'So say we all...': '我们都说...',
-  'Loading the next great idea...': '正在加载下一个伟大的想法...',
-  "Just a moment, I'm in the zone...": '稍等片刻，我正进入状态...',
-  'Preparing to dazzle you with brilliance...': '正在准备用智慧让您眼花缭乱...',
-  "Just a tick, I'm polishing my wit...": '稍等片刻，我正在打磨我的智慧...',
-  "Hold tight, I'm crafting a masterpiece...": '请稍等，我正在制作杰作...',
-  "Just a jiffy, I'm debugging the universe...": '稍等片刻，我正在调试宇宙...',
-  "Just a moment, I'm aligning the pixels...": '稍等片刻，我正在对齐像素...',
-  "Just a sec, I'm optimizing the humor...": '稍等片刻，我正在优化幽默感...',
-  "Just a moment, I'm tuning the algorithms...": '稍等片刻，我正在调整算法...',
-  'Warp speed engaged...': '曲速已启动...',
-  'Mining for more Dilithium crystals...': '正在挖掘更多二锂晶体...',
-  "Don't panic...": '不要惊慌...',
-  'Following the white rabbit...': '正在跟随白兔...',
-  'The truth is in here... somewhere...': '真相在这里...某个地方...',
-  'Blowing on the cartridge...': '正在吹卡带...',
-  'Loading... Do a barrel roll!': '正在加载...做个桶滚！',
-  'Waiting for the respawn...': '等待重生...',
-  'Finishing the Kessel Run in less than 12 parsecs...':
-    '正在以不到 12 秒差距完成凯塞尔航线...',
-  "The cake is not a lie, it's just still loading...":
-    '蛋糕不是谎言，只是还在加载...',
-  'Fiddling with the character creation screen...': '正在摆弄角色创建界面...',
-  "Just a moment, I'm finding the right meme...":
-    '稍等片刻，我正在寻找合适的表情包...',
-  "Pressing 'A' to continue...": "按 'A' 继续...",
-  'Herding digital cats...': '正在放牧数字猫...',
-  'Polishing the pixels...': '正在打磨像素...',
-  'Finding a suitable loading screen pun...': '正在寻找合适的加载屏幕双关语...',
-  'Distracting you with this witty phrase...':
-    '正在用这个机智的短语分散您的注意力...',
-  'Almost there... probably...': '快到了...可能...',
-  'Our hamsters are working as fast as they can...':
-    '我们的仓鼠正在尽可能快地工作...',
-  'Giving Cloudy a pat on the head...': '正在拍拍 Cloudy 的头...',
-  'Petting the cat...': '正在抚摸猫咪...',
-  'Rickrolling my boss...': '正在 Rickroll 我的老板...',
-  'Never gonna give you up, never gonna let you down...':
-    '永远不会放弃你，永远不会让你失望...',
-  'Slapping the bass...': '正在拍打低音...',
-  'Tasting the snozberries...': '正在品尝 snozberries...',
-  "I'm going the distance, I'm going for speed...":
-    '我要走得更远，我要追求速度...',
-  'Is this the real life? Is this just fantasy?...':
-    '这是真实的生活吗？还是只是幻想？...',
-  "I've got a good feeling about this...": '我对这个感觉很好...',
-  'Poking the bear...': '正在戳熊...',
-  'Doing research on the latest memes...': '正在研究最新的表情包...',
-  'Figuring out how to make this more witty...': '正在想办法让这更有趣...',
-  'Hmmm... let me think...': '嗯...让我想想...',
-  'What do you call a fish with no eyes? A fsh...':
-    '没有眼睛的鱼叫什么？一条鱼...',
-  'Why did the computer go to therapy? It had too many bytes...':
-    '为什么电脑去看心理医生？因为它有太多字节...',
-  "Why don't programmers like nature? It has too many bugs...":
-    '为什么程序员不喜欢大自然？因为虫子太多了...',
-  'Why do programmers prefer dark mode? Because light attracts bugs...':
-    '为什么程序员喜欢暗色模式？因为光会吸引虫子...',
-  'Why did the developer go broke? Because they used up all their cache...':
-    '为什么开发者破产了？因为他们用完了所有缓存...',
-  "What can you do with a broken pencil? Nothing, it's pointless...":
-    '你能用断了的铅笔做什么？什么都不能，因为它没有笔尖...',
-  'Applying percussive maintenance...': '正在应用敲击维护...',
-  'Searching for the correct USB orientation...': '正在寻找正确的 USB 方向...',
-  'Ensuring the magic smoke stays inside the wires...':
-    '确保魔法烟雾留在电线内...',
-  'Rewriting in Rust for no particular reason...':
-    '正在用 Rust 重写，没有特别的原因...',
-  'Trying to exit Vim...': '正在尝试退出 Vim...',
-  'Spinning up the hamster wheel...': '正在启动仓鼠轮...',
-  "That's not a bug, it's an undocumented feature...":
-    '这不是一个错误，这是一个未记录的功能...',
-  'Engage.': '启动。',
-  "I'll be back... with an answer.": '我会回来的...带着答案。',
-  'My other process is a TARDIS...': '我的另一个进程是 TARDIS...',
-  'Communing with the machine spirit...': '正在与机器精神交流...',
-  'Letting the thoughts marinate...': '让想法慢慢酝酿...',
-  'Just remembered where I put my keys...': '刚刚想起我把钥匙放在哪里了...',
-  'Pondering the orb...': '正在思考球体...',
-  "I've seen things you people wouldn't believe... like a user who reads loading messages.":
-    '我见过你们不会相信的事情...比如一个阅读加载消息的用户。',
-  'Initiating thoughtful gaze...': '正在启动深思凝视...',
-  "What's a computer's favorite snack? Microchips.":
-    '电脑最喜欢的零食是什么？微芯片。',
-  "Why do Java developers wear glasses? Because they don't C#.":
-    '为什么 Java 开发者戴眼镜？因为他们不会 C#。',
-  'Charging the laser... pew pew!': '正在给激光充电...砰砰！',
-  'Dividing by zero... just kidding!': '除以零...只是开玩笑！',
-  'Looking for an adult superviso... I mean, processing.':
-    '正在寻找成人监督...我是说，处理中。',
-  'Making it go beep boop.': '让它发出哔哔声。',
-  'Buffering... because even AIs need a moment.':
-    '正在缓冲...因为即使是 AI 也需要片刻。',
-  'Entangling quantum particles for a faster response...':
-    '正在纠缠量子粒子以获得更快的回复...',
-  'Polishing the chrome... on the algorithms.': '正在打磨铬...在算法上。',
-  'Are you not entertained? (Working on it!)': '你不觉得有趣吗？（正在努力！）',
-  'Summoning the code gremlins... to help, of course.':
-    '正在召唤代码小精灵...当然是来帮忙的。',
-  'Just waiting for the dial-up tone to finish...': '只是等待拨号音结束...',
-  'Recalibrating the humor-o-meter.': '正在重新校准幽默计。',
-  'My other loading screen is even funnier.': '我的另一个加载屏幕更有趣。',
-  "Pretty sure there's a cat walking on the keyboard somewhere...":
-    '很确定有只猫在某个地方键盘上走...',
-  'Enhancing... Enhancing... Still loading.':
-    '正在增强...正在增强...仍在加载。',
-  "It's not a bug, it's a feature... of this loading screen.":
-    '这不是一个错误，这是一个功能...这个加载屏幕的功能。',
-  'Have you tried turning it off and on again? (The loading screen, not me.)':
-    '你试过把它关掉再打开吗？（加载屏幕，不是我。）',
-  'Constructing additional pylons...': '正在建造额外的能量塔...',
+  WITTY_LOADING_PHRASES: [
+    // --- 职场搬砖系列 ---
+    '正在努力搬砖，请稍候...',
+    '老板在身后，快加载啊！',
+    '头发掉光前，一定能加载完...',
+    '服务器正在深呼吸，准备放大招...',
+    '正在向服务器投喂咖啡...',
+
+    // --- 大厂黑话系列 ---
+    '正在赋能全链路，寻找关键抓手...',
+    '正在降本增效，优化加载路径...',
+    '正在打破部门壁垒，沉淀方法论...',
+    '正在拥抱变化，迭代核心价值...',
+    '正在对齐颗粒度，打磨底层逻辑...',
+    '大力出奇迹，正在强行加载...',
+
+    // --- 程序员自嘲系列 ---
+    '只要我不写代码，代码就没有 Bug...',
+    '正在把 Bug 转化为 Feature...',
+    '只要我不尴尬，Bug 就追不上我...',
+    '正在试图理解去年的自己写了什么...',
+    '正在猿力觉醒中，请耐心等待...',
+
+    // --- 合作愉快系列 ---
+    '正在询问产品经理：这需求是真的吗？',
+    '正在给产品经理画饼，请稍等...',
+
+    // --- 温暖治愈系列 ---
+    '每一行代码，都在努力让世界变得更好一点点...',
+    '每一个伟大的想法，都值得这份耐心的等待...',
+    '别急，美好的事物总是需要一点时间去酝酿...',
+    '愿你的代码永无 Bug，愿你的梦想终将成真...',
+    '哪怕只有 0.1% 的进度，也是在向目标靠近...',
+    '加载的是字节，承载的是对技术的热爱...',
+  ],
+
+  // ============================================================================
+  // Extension Settings Input
+  // ============================================================================
+  'Enter value...': '请输入值...',
+  'Enter sensitive value...': '请输入敏感值...',
+  'Press Enter to submit, Escape to cancel': '按 Enter 提交，Escape 取消',
+
+  // ============================================================================
+  // Command Migration Tool
+  // ============================================================================
+  'Markdown file already exists: {{filename}}':
+    'Markdown 文件已存在：{{filename}}',
+  'TOML Command Format Deprecation Notice': 'TOML 命令格式弃用通知',
+  'Found {{count}} command file(s) in TOML format:':
+    '发现 {{count}} 个 TOML 格式的命令文件：',
+  'The TOML format for commands is being deprecated in favor of Markdown format.':
+    '命令的 TOML 格式正在被弃用，推荐使用 Markdown 格式。',
+  'Markdown format is more readable and easier to edit.':
+    'Markdown 格式更易读、更易编辑。',
+  'You can migrate these files automatically using:':
+    '您可以使用以下命令自动迁移这些文件：',
+  'Or manually convert each file:': '或手动转换每个文件：',
+  'TOML: prompt = "..." / description = "..."':
+    'TOML：prompt = "..." / description = "..."',
+  'Markdown: YAML frontmatter + content': 'Markdown：YAML frontmatter + 内容',
+  'The migration tool will:': '迁移工具将：',
+  'Convert TOML files to Markdown': '将 TOML 文件转换为 Markdown',
+  'Create backups of original files': '创建原始文件的备份',
+  'Preserve all command functionality': '保留所有命令功能',
+  'TOML format will continue to work for now, but migration is recommended.':
+    'TOML 格式目前仍可使用，但建议迁移。',
+
+  // ============================================================================
+  // Extensions - Explore Command
+  // ============================================================================
+  'Open extensions page in your browser': '在浏览器中打开扩展市场页面',
+  'Unknown extensions source: {{source}}.': '未知的扩展来源：{{source}}。',
+  'Would open extensions page in your browser: {{url}} (skipped in test environment)':
+    '将在浏览器中打开扩展页面：{{url}}（测试环境中已跳过）',
+  'View available extensions at {{url}}': '在 {{url}} 查看可用扩展',
+  'Opening extensions page in your browser: {{url}}':
+    '正在浏览器中打开扩展页面：{{url}}',
+  'Failed to open browser. Check out the extensions gallery at {{url}}':
+    '打开浏览器失败。请访问扩展市场：{{url}}',
 };
